/* fi_lib q_errm.c adapted for use with Lua */

#define NAN_ERR -1

static void fi_abort(int n, int fctn)
{
	(void)(fctn);
	const char *message;
	if (n==INV_ARG)
		message="invalid argument";
	else if (n==OVER_FLOW)
		message="overflow";
	else if (n==DIV_ZERO)
		message="division by zero";
	else if (n==NAN_ERR)
		message="nan argument";
	else
		message="cannot happen";
	luaL_error(LL,"(fi_lib) %s",message);
}

static double q_abort(int n, double *x, int fctn)
{
	fi_abort(n,fctn);
	return *x;
}

static interval j_abort(int n, double *x1, double *x2, int fctn)
{
	interval res;
	fi_abort(n,fctn);
	res.INF=*x1;
	res.SUP=*x2;
	return res;
}

local double q_abortnan(int n, double *x, int fctn)
{
	(void)(n);
	return q_abort(NAN_ERR,x,fctn);
}

local double q_abortr1(int n, double *x, int fctn)
{
	return q_abort(n,x,fctn);
}

local interval q_abortr2(int n, double *x1, double *x2, int fctn)
{
	return j_abort(n,x1,x2,fctn);
}

local double q_abortdivd(int n, double *x)
{
	return q_abort(n,x,-1);
}

local interval q_abortdivi(int n, double *x1, double *x2)
{
	return j_abort(n,x1,x2,-1);
}

